@@ -9,9 +9,9 @@ use Cwd;
 use Exporter qw(import);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-02-14'; # DATE
+our $DATE = '2023-02-15'; # DATE
 our $DIST = 'App-CSVUtils'; # DIST
-our $VERSION = '1.011'; # VERSION
+our $VERSION = '1.012'; # VERSION
 
 our @EXPORT_OK = qw(
                        gen_csv_util
@@ -308,7 +308,7 @@ sub _select_fields {
     [100, "Continue", [\@selected_fields, \@selected_field_idxs_array]];
 }
 
-our $xcomp_csvfiles = [filename => {file_ext_filter => qr/\.[tc]sv$/i}];
+our $xcomp_csvfiles = [filename => {file_ext_filter => qr/^[tc]sv$/i}];
 
 our %argspecs_csv_input = (
     input_header => {
@@ -1633,6 +1633,12 @@ sub gen_csv_util {
                                 }
 
                             } else {
+                                # fill up the elements of row to the number of
+                                # fields, in case the row contains sparse values
+                                if (@{ $r->{input_row} } < @{ $r->{input_fields} }) {
+                                    splice @{ $r->{input_row} }, scalar(@{ $r->{input_row} }), 0, (("") x (@{ $r->{input_fields} } - @{ $r->{input_row} }));
+                                }
+
                                 # generate the hashref version of row if utility
                                 # requires it
                                 if ($r->{wants_input_row_as_hashref}) {
@@ -1710,7 +1716,11 @@ sub gen_csv_util {
                     delete $r->{output_fh};
                 }
                 if ($r->{util_args}{inplace}) {
+                    my $output_filenum = $r->{output_filenum} // 0;
+                    my $i = -1;
                     for my $output_filename (@{ $r->{output_filenames} }) {
+                        $i++;
+                        last if $i > $output_filenum;
                         (my $input_filename = $output_filename) =~ s/\.\w{5}\z//
                             or die [500, "BUG: Can't get original input file '$output_filename'"];
                         if (length(my $ext = $r->{util_args}{inplace_backup_ext})) {
@@ -1856,7 +1866,7 @@ App::CSVUtils - CLI utilities related to CSV
 
 =head1 VERSION
 
-This document describes version 1.011 of App::CSVUtils (from Perl distribution App-CSVUtils), released on 2023-02-14.
+This document describes version 1.012 of App::CSVUtils (from Perl distribution App-CSVUtils), released on 2023-02-15.
 
 =head1 DESCRIPTION
 
@@ -1868,11 +1878,11 @@ This distribution contains the following CLI utilities:
 
 =item * L<csv-avg>
 
-=item * L<csv-check-cell>
+=item * L<csv-check-cell-values>
 
-=item * L<csv-check-field>
+=item * L<csv-check-field-names>
 
-=item * L<csv-check-values>
+=item * L<csv-check-field-values>
 
 =item * L<csv-concat>
 
