@@ -5,9 +5,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-02-14'; # DATE
+our $DATE = '2023-02-15'; # DATE
 our $DIST = 'App-CSVUtils'; # DIST
-our $VERSION = '1.011'; # VERSION
+our $VERSION = '1.012'; # VERSION
 
 use App::CSVUtils qw(
                         gen_csv_util
@@ -94,7 +94,7 @@ _
 
         # check arguments
         if (!defined($r->{util_args}{fields}) || !@{ $r->{util_args}{fields} }) {
-            die [400, "Please specify one or more fields (-F)"];
+            die [400, "Please specify one or more fields (-f)"];
         }
     },
 
@@ -182,7 +182,7 @@ App::CSVUtils::csv_add_fields - Add one or more fields to CSV file
 
 =head1 VERSION
 
-This document describes version 1.011 of App::CSVUtils::csv_add_fields (from Perl distribution App-CSVUtils), released on 2023-02-14.
+This document describes version 1.012 of App::CSVUtils::csv_add_fields (from Perl distribution App-CSVUtils), released on 2023-02-15.
 
 =head1 FUNCTIONS
 
